==> PrjForInfCreditVilFW-0.1.1.tar.gz: PrjForInfCreditVilFW-0.1.1/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['prjforinfcreditvilfw',
 'prjforinfcreditvilfw.analyze',
 'prjforinfcreditvilfw.analyze.csvcheck',
 'prjforinfcreditvilfw.boto3aws',
 'prjforinfcreditvilfw.boto3aws.aws_batch',
 'prjforinfcreditvilfw.boto3aws.aws_ec2',
 'prjforinfcreditvilfw.boto3aws.aws_ecr',
 'prjforinfcreditvilfw.boto3aws.aws_ecr.container',
 'prjforinfcreditvilfw.boto3aws.aws_fargate',
 'prjforinfcreditvilfw.boto3aws.aws_s3',
 'prjforinfcreditvilfw.boto3aws.manageaws',
 'prjforinfcreditvilfw.boto3aws.tools',
 'prjforinfcreditvilfw.dataandgrid',
 'prjforinfcreditvilfw.dataandgrid.choices',
 'prjforinfcreditvilfw.dataandgrid.choices.dynamic',
 'prjforinfcreditvilfw.dataandgrid.choices.dynamic.test_dynamic',
 'prjforinfcreditvilfw.dataandgrid.choices.fixed',
 'prjforinfcreditvilfw.dataandgrid.choices.fixed.fixedtest_fixed',
 'prjforinfcreditvilfw.dataandgrid.test_dataandgrid',
 'prjforinfcreditvilfw.estimation',
 'prjforinfcreditvilfw.estimation.moments',
 'prjforinfcreditvilfw.estimation.postprocess',
 'prjforinfcreditvilfw.estimation.postprocess.jsoncsv',
 'prjforinfcreditvilfw.estimation.postprocess.texdo',
 'prjforinfcreditvilfw.estimation.saveesticomp',
 'prjforinfcreditvilfw.estimation.test_estimation',
 'prjforinfcreditvilfw.invoke',
 'prjforinfcreditvilfw.invoke.run_aws_esti_sync',
 'prjforinfcreditvilfw.invoke.run_aws_esti_sync.cs',
 'prjforinfcreditvilfw.invoke.test_invoke',
 'prjforinfcreditvilfw.modelhh',
 'prjforinfcreditvilfw.modelhh.functions',
 'prjforinfcreditvilfw.modelhh.functions.test_functions',
 'prjforinfcreditvilfw.modelhh.future',
 'prjforinfcreditvilfw.modelhh.future.test_future',
 'prjforinfcreditvilfw.modelhh.test_modelhh',
 'prjforinfcreditvilfw.parameters',
 'prjforinfcreditvilfw.parameters.data',
 'prjforinfcreditvilfw.parameters.dist',
 'prjforinfcreditvilfw.parameters.esti',
 'prjforinfcreditvilfw.parameters.grid',
 'prjforinfcreditvilfw.parameters.interpolant',
 'prjforinfcreditvilfw.parameters.json',
 'prjforinfcreditvilfw.parameters.loop_combo_type_list',
 'prjforinfcreditvilfw.parameters.loop_param_combo_list',
 'prjforinfcreditvilfw.parameters.minmax',
 'prjforinfcreditvilfw.parameters.model',
 'prjforinfcreditvilfw.parameters.paramset',
 'prjforinfcreditvilfw.parameters.runspecs',
 'prjforinfcreditvilfw.parameters.test_parameters',
 'prjforinfcreditvilfw.projectsupport',
 'prjforinfcreditvilfw.projectsupport.datamanage',
 'prjforinfcreditvilfw.projectsupport.graph',
 'prjforinfcreditvilfw.projectsupport.hardcode',
 'prjforinfcreditvilfw.projectsupport.stationary_agg',
 'prjforinfcreditvilfw.soluequi',
 'prjforinfcreditvilfw.solusteady',
 'prjforinfcreditvilfw.solusteady.distribution',
 'prjforinfcreditvilfw.solusteady.test_simuequi',
 'prjforinfcreditvilfw.soluvalue',
 'prjforinfcreditvilfw.soluvalue.test_soluvalue',
 'prjforinfcreditvilfw.soluvalue.tools',
 'prjforinfcreditvilfw.vig',
 'prjforinfcreditvilfw.vig.estirandinit',
 'prjforinfcreditvilfw.vig.estisimurand.sall_aws',
 'prjforinfcreditvilfw.vig.estisimurand.sall_aws_sandbox.template',
 'prjforinfcreditvilfw.vig.estisimurand.sall_aws_sandbox.template_onefile',
 'prjforinfcreditvilfw.vig.estisimurand.sall_aws_sandbox.working',
 'prjforinfcreditvilfw.vig.estisimurand.sall_local',
 'prjforinfcreditvilfw.vig.estisimurand.sall_local_sandbox.working_cmd',
 'prjforinfcreditvilfw.vig.estisimurand.sandbox',
 'prjforinfcreditvilfw.vig.parameters',
 'prjforinfcreditvilfw.vig.parameters.combo_type',
 'prjforinfcreditvilfw.vig.parameters.compesti_specs',
 'prjforinfcreditvilfw.vig.parameters.param_combo',
 'prjforinfcreditvilfw.vig.simucounter',
 'prjforinfcreditvilfw.vig.simucounter.cev_test_local',
 'prjforinfcreditvilfw.vig.simucounter.cev_test_parser',
 'prjforinfcreditvilfw.vig.simugridrand',
 'prjforinfcreditvilfw.vig.simugridrand.a_simugrid',
 'prjforinfcreditvilfw.vig.simugridrand.b_simugrid_momobj',
 'prjforinfcreditvilfw.vig.simugridrand.c_simurand_momobj',
 'prjforinfcreditvilfw.vig.simupoint']

package_data = \
{'': ['*'],
 'prjforinfcreditvilfw.boto3aws': ['aws_ec2/pem/*'],
 'prjforinfcreditvilfw.parameters': ['json/c_20180901_ITG_list_Adist/*',
                                     'json/c_20180901_ITG_list_tKap/*',
                                     'json/c_20180901_list_tall/*',
                                     'json/c_20180901x_ITG_list_Adist/*',
                                     'json/c_20180901x_ITG_list_tKap/*',
                                     'json/c_20180901x_list_tKap/*',
                                     'json/c_20180918_ITG_list_tall/*',
                                     'json/c_20180918x_ITG_list_Adist/*',
                                     'json/c_20180918x_list_tKap/*',
                                     'json/c_20180925_ITG_list_Afx3/*',
                                     'json/c_20180925x_ITG_list_Adist/*',
                                     'json/c_20180925x_list_tKap/*'],
 'prjforinfcreditvilfw.vig': ['estisimurand/*',
                              'estisimurand/sall_aws_sandbox/*',
                              'estisimurand/sall_local_sandbox/*',
                              'estisimurand/sall_local_sandbox/template_cmd/*',
                              'simugrid/*']}

install_requires = \
['boto3>=1.15.18,<2.0.0',
 'cython>=0.29.20,<0.30.0',
 'matplotlib>=3.2.1,<4.0.0',
 'numba>=0.50.1,<0.51.0',
 'numpy>=1.18.5,<2.0.0',
 'python-frontmatter>=0.5.0,<0.6.0',
 'pyyaml>=5.3.1,<6.0.0',
 'scipy>=1.4.1,<2.0.0',
 'seaborn>=0.10.1,<0.11.0',
 'sklearn>=0.0,<0.1',
 'statsmodels>=0.11.1,<0.12.0',
 'urllib3>=1.25.10,<2.0.0']

setup_kwargs = {
    'name': 'prjforinfcreditvilfw',
    'version': '0.1.1',
    'description': '',
    'long_description': None,
    'author': 'Fan Wang',
    'author_email': 'wangfanbsg75@live.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)

==> PrjForInfCreditVilFW-0.1.2.tar.gz: PrjForInfCreditVilFW-0.1.2/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['prjforinfcreditvilfw',
 'prjforinfcreditvilfw.analyze',
 'prjforinfcreditvilfw.analyze.csvcheck',
 'prjforinfcreditvilfw.boto3aws',
 'prjforinfcreditvilfw.boto3aws.aws_batch',
 'prjforinfcreditvilfw.boto3aws.aws_ec2',
 'prjforinfcreditvilfw.boto3aws.aws_ecr',
 'prjforinfcreditvilfw.boto3aws.aws_ecr.container',
 'prjforinfcreditvilfw.boto3aws.aws_fargate',
 'prjforinfcreditvilfw.boto3aws.aws_s3',
 'prjforinfcreditvilfw.boto3aws.manageaws',
 'prjforinfcreditvilfw.boto3aws.tools',
 'prjforinfcreditvilfw.dataandgrid',
 'prjforinfcreditvilfw.dataandgrid.choices',
 'prjforinfcreditvilfw.dataandgrid.choices.dynamic',
 'prjforinfcreditvilfw.dataandgrid.choices.dynamic.test_dynamic',
 'prjforinfcreditvilfw.dataandgrid.choices.fixed',
 'prjforinfcreditvilfw.dataandgrid.choices.fixed.fixedtest_fixed',
 'prjforinfcreditvilfw.dataandgrid.test_dataandgrid',
 'prjforinfcreditvilfw.estimation',
 'prjforinfcreditvilfw.estimation.moments',
 'prjforinfcreditvilfw.estimation.postprocess',
 'prjforinfcreditvilfw.estimation.postprocess.jsoncsv',
 'prjforinfcreditvilfw.estimation.postprocess.texdo',
 'prjforinfcreditvilfw.invoke',
 'prjforinfcreditvilfw.invoke.run_aws_esti_sync',
 'prjforinfcreditvilfw.invoke.run_aws_esti_sync.cs',
 'prjforinfcreditvilfw.modelhh',
 'prjforinfcreditvilfw.modelhh.functions',
 'prjforinfcreditvilfw.modelhh.functions.test_functions',
 'prjforinfcreditvilfw.modelhh.future',
 'prjforinfcreditvilfw.modelhh.future.test_future',
 'prjforinfcreditvilfw.modelhh.test_modelhh',
 'prjforinfcreditvilfw.parameters',
 'prjforinfcreditvilfw.parameters.data',
 'prjforinfcreditvilfw.parameters.dist',
 'prjforinfcreditvilfw.parameters.esti',
 'prjforinfcreditvilfw.parameters.grid',
 'prjforinfcreditvilfw.parameters.interpolant',
 'prjforinfcreditvilfw.parameters.loop_combo_type_list',
 'prjforinfcreditvilfw.parameters.loop_param_combo_list',
 'prjforinfcreditvilfw.parameters.minmax',
 'prjforinfcreditvilfw.parameters.model',
 'prjforinfcreditvilfw.parameters.paramset',
 'prjforinfcreditvilfw.parameters.runspecs',
 'prjforinfcreditvilfw.parameters.test_parameters',
 'prjforinfcreditvilfw.projectsupport',
 'prjforinfcreditvilfw.projectsupport.datamanage',
 'prjforinfcreditvilfw.projectsupport.graph',
 'prjforinfcreditvilfw.projectsupport.hardcode',
 'prjforinfcreditvilfw.soluequi',
 'prjforinfcreditvilfw.solusteady',
 'prjforinfcreditvilfw.solusteady.distribution',
 'prjforinfcreditvilfw.solusteady.test_simuequi',
 'prjforinfcreditvilfw.soluvalue',
 'prjforinfcreditvilfw.soluvalue.test_soluvalue',
 'prjforinfcreditvilfw.vig',
 'prjforinfcreditvilfw.vig.estisimurand.sall_aws',
 'prjforinfcreditvilfw.vig.estisimurand.sall_aws_sandbox.template',
 'prjforinfcreditvilfw.vig.estisimurand.sall_aws_sandbox.template_onefile',
 'prjforinfcreditvilfw.vig.estisimurand.sall_aws_sandbox.working',
 'prjforinfcreditvilfw.vig.estisimurand.sall_local',
 'prjforinfcreditvilfw.vig.estisimurand.sall_local_sandbox.working_cmd',
 'prjforinfcreditvilfw.vig.parameters',
 'prjforinfcreditvilfw.vig.parameters.combo_type',
 'prjforinfcreditvilfw.vig.parameters.compesti_specs',
 'prjforinfcreditvilfw.vig.parameters.param_combo',
 'prjforinfcreditvilfw.vig.simucounter',
 'prjforinfcreditvilfw.vig.simucounter.cev_test_local',
 'prjforinfcreditvilfw.vig.simucounter.cev_test_parser',
 'prjforinfcreditvilfw.vig.simugridrand',
 'prjforinfcreditvilfw.vig.simugridrand.a_simugrid',
 'prjforinfcreditvilfw.vig.simugridrand.b_simugrid_momobj',
 'prjforinfcreditvilfw.vig.simugridrand.c_simurand_momobj',
 'prjforinfcreditvilfw.vig.simupoint']

package_data = \
{'': ['*'],
 'prjforinfcreditvilfw.boto3aws': ['aws_ec2/pem/*'],
 'prjforinfcreditvilfw.vig': ['estisimurand/sall_local_sandbox/template_cmd/*']}

install_requires = \
['boto3>=1.15.18,<2.0.0',
 'cryptography>=3.0.0,<4.0.0',
 'cython>=0.29.20,<0.30.0',
 'interpolation>=2.0.0,<3.0.0',
 'matplotlib>=3.2.1,<4.0.0',
 'numba>=0.50.1,<0.51.0',
 'numpy>=1.18.5,<2.0.0',
 'pyfan>=0.1.0,<0.2.0',
 'python-frontmatter>=0.5.0,<0.6.0',
 'pyyaml>=5.3.1,<6.0.0',
 'scipy>=1.4.1,<2.0.0',
 'seaborn>=0.10.1,<0.11.0',
 'sklearn>=0.0,<0.1',
 'statsmodels>=0.11.1,<0.12.0',
 'urllib3>=1.25.10,<2.0.0']

setup_kwargs = {
    'name': 'prjforinfcreditvilfw',
    'version': '0.1.2',
    'description': '',
    'long_description': None,
    'author': 'Fan Wang',
    'author_email': 'wangfanbsg75@live.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
